#
# spec file for package log4j
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define bootstrap 0
# Needed as it is split to log4j-mini
%define real log4j
Name:           log4j
# This line is not a comment, please do not remove it!
#%(sh %{_sourcedir}/jpackage-mini-prepare.sh %{_sourcedir} %{name})
Version:        1.2.17
Release:        5.9.1
Summary:        Java logging tool
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://logging.apache.org/log4j/
Source0:        http://www.apache.org/dist/logging/log4j/%{version}/log4j-%{version}.tar.gz
# Converted from src/java/org/apache/log4j/lf5/viewer/images/lf5_small_icon.gif
Source1:        %{real}-logfactor5.png
Source2:        %{real}-logfactor5.sh
Source3:        %{real}-logfactor5.desktop
# Converted from docs/images/logo.jpg
Source7:        %{real}.catalog
Source1000:     jpackage-mini-prepare.sh
Patch0:         %{real}-logfactor5-userdir.patch
Patch1:         %{real}-javadoc-xlink.patch
Patch2:         %{real}-mx4j-tools.patch
# PATCH-FIX-OPENSUSE -- Drop javadoc timestamp
Patch3:         %{real}-reproducible.patch
# PATCH-FIX-UPSTREAM bsc#1159646 CVE-2019-17571 deserialization of untrusted data in SocketServer
Patch4:         log4j-CVE-2019-17571.patch
Patch6:         log4j-missingmodules.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  jndi
BuildRequires:  perl
BuildRequires:  update-desktop-files
Requires:       javapackages-tools
Requires:       jaxp_parser_impl
Requires:       xml-commons-apis
Obsoletes:      chainsaw < 2.1
Requires(pre):  coreutils
BuildArch:      noarch
%if %{bootstrap}
Provides:       %{real} = %{version}-%{release}
%endif
%if ! %{bootstrap}
BuildRequires:  classpathx-mail
BuildRequires:  geronimo-jaf-1_0_2-api
BuildRequires:  geronimo-jms-1_1-api
BuildRequires:  mx4j
#!BuildIgnore:  apache-commons-discovery
#!BuildIgnore:  apache-commons-logging
#!BuildIgnore:  axis
%endif
%if %{bootstrap}
Conflicts:      log4j
%else
Conflicts:      log4j-mini
%endif

%description
Log4j is a tool to help the programmer output log statements to a
variety of output targets.

%if ! %{bootstrap}
%package        manual
Summary:        Java logging tool (Manual)
Group:          Development/Libraries/Java

%description    manual
Documentation manual for Java logging tool log4j.

%package        javadoc
Summary:        Java logging tool (Documentation)
Group:          Development/Libraries/Java

%description    javadoc
Documentation javadoc for Java logging tool log4j.

%package      -n logfactor5
Summary:        Log Viewer GUI
Group:          Development/Tools/Navigators

%description -n logfactor5
LogFactor5 is a Swing based GUI to view log4j logs.

%endif

%prep
%setup -q -n apache-log4j-%{version}
%patch0
%patch1
%patch2
%patch3 -p1
%patch4 -p1
%patch6 -p1

sed -i 's/\r//g' LICENSE NOTICE src/site/resources/css/*.css

# remove all the stuff we'll build ourselves
find . \( -name "*.jar" -o -name "*.class" \) -exec rm -f {} \;
rm -rf docs/api

# fix encoding of mailbox files
for i in contribs/JimMoore/mail*;do
    iconv --from=ISO-8859-1 --to=UTF-8 "$i" > new
    mv new "$i"
done

# CVE-2022-23302 [bsc#1194842] and CVE-2022-23305 [bsc#1194843]
rm src/main/java/org/apache/log4j/net/JMSAppender.java \
   src/main/java/org/apache/log4j/net/JMSSink.java \
   src/main/java/org/apache/log4j/jdbc/JDBCAppender.java

%build
ant \
        -Djavamail.jar=$(build-classpath javamail/mailapi) \
        -Dactivation.jar=$(build-classpath jaf) \
        -Djaxp.jaxp.jar.jar=$(build-classpath jaxp_parser_impl) \
        -Djms.jar=$(build-classpath jms) \
        -Djmx.jar=$(build-classpath mx4j/mx4j) \
        -Djmx-extra.jar=$(build-classpath mx4j/mx4j-tools) \
        -Djndi.jar=$(build-classpath jndi) \
        -Djavac.source=1.6 -Djavac.target=1.6 \
        -Djdk.javadoc=%{_javadocdir}/java \
        jar \
%if ! %{bootstrap}
        javadoc
%endif

%install
# jars
mkdir -p %{buildroot}%{_javadir}
cp -a dist/lib/log4j-%{version}.jar %{buildroot}%{_javadir}
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)
%if ! %{bootstrap}
# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -a docs/api/* %{buildroot}%{_javadocdir}/%{name}
rm -rf docs/api
ln -s %{_javadocdir}/%{name} docs/api

# scripts
mkdir -p %{buildroot}%{_bindir}
install -p -m 755 %{SOURCE2} %{buildroot}%{_bindir}/logfactor5

# freedesktop.org menu entries and icons
mkdir -p %{buildroot}%{_datadir}/{applications,pixmaps}
cp -a %{SOURCE1} \
  %{buildroot}%{_datadir}/pixmaps/logfactor5.png
cp -a %{SOURCE3} \
  %{buildroot}%{_datadir}/applications/jpackage-logfactor5.desktop

# fix perl location
perl -p -i -e 's|/opt/perl5/bin/perl|perl|' \
contribs/KitchingSimon/udpserver.pl
%suse_update_desktop_file jpackage-logfactor5 Development Debugger

%endif

# DTD and the SGML catalog (XML catalog handled in scriptlets)
mkdir -p %{buildroot}%{_datadir}/sgml/%{name}
cp -a src/main/resources/org/apache/log4j/xml/log4j.dtd \
  %{buildroot}%{_datadir}/sgml/%{name}
cp -a %{SOURCE7} \
  %{buildroot}%{_datadir}/sgml/%{name}/catalog

%fdupes -s %{buildroot}%{_javadocdir}

%post
# Note that we're using versioned catalog, so this is always ok.
if [ -x %{_bindir}/install-catalog -a -d %{_sysconfdir}/sgml ]; then
  %{_bindir}/install-catalog --add \
    %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat \
    %{_datadir}/sgml/%{name}/catalog > /dev/null || :
fi
if [ -x %{_bindir}/xmlcatalog -a -w %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --add system log4j.dtd \
    file://%{_datadir}/sgml/%{name}/log4j.dtd %{_sysconfdir}/xml/catalog \
    > /dev/null || :
fi

%preun
if [ $1 -eq 0 ]; then
  if [ -x %{_bindir}/xmlcatalog -a -w %{_sysconfdir}/xml/catalog ]; then
    %{_bindir}/xmlcatalog --noout --del log4j.dtd \
      %{_sysconfdir}/xml/catalog > /dev/null || :
  fi
fi

%postun
# Note that we're using versioned catalog, so this is always ok.
if [ -x %{_bindir}/install-catalog -a -d %{_sysconfdir}/sgml ]; then
  %{_bindir}/install-catalog --remove \
    %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat \
    %{_datadir}/sgml/%{name}/catalog > /dev/null || :
fi

%files
%license LICENSE
%doc NOTICE
%{_javadir}/*
%{_datadir}/sgml/%{name}

%if ! %{bootstrap}
%files manual
%doc docs/* contribs

%files javadoc
%dir %{_javadocdir}/%{name}
%{_javadocdir}/%{name}/*

%files -n logfactor5
%{_bindir}/logfactor5
%{_datadir}/applications/jpackage-logfactor5.desktop
%{_datadir}/pixmaps/logfactor5.png
%endif

%changelog
* Wed Jan 19 2022 fstrba@suse.com
- Remove the chainsaw sub-package (bsc#1194844, CVE-2022-23307)
- Remove src/main/java/org/apache/log4j/jdbc/JDBCAppender.java from
  the build to mitigate bsc#1194843, CVE-2022-23305
- Remove src/main/java/org/apache/log4j/net/JMSSink.java from the
  build to mitigate bsc#1194842, CVE-2022-23302
- Obsolete chainsaw < 2.1 by the log4j package
- Added patch:
  * log4j-missingmodules.patch
    + do not package org.apache.log4j.chainsaw classes
    + package org.apache.log4j.pattern classes that will be needed
    by apache-log4j-extras which is a dependency of chainsaw 2.x
* Thu Dec 16 2021 psimons@suse.com
- Remove src/main/java/org/apache/log4j/net/JMSAppender.java from
  the build to mitigate CVE-2021-4104. [bsc#1193662]
* Thu Jan  2 2020 pmonrealgonzalez@suse.com
- Security fix: [bsc#1159646, CVE-2019-17571]
  * Remote code execution: Deserialization of untrusted data in SocketServer
  * Backported from CVE-2017-5645 for Log4j 2.8.2
- Add log4j-CVE-2019-17571.patch
- Use fdupes macro to avoid duplicated files
* Wed Jan 10 2018 bwiedemann@suse.com
- Add log4j-reproducible.patch to drop javadoc timestamps to make
  package builds more reproducible (boo#1047218)
* Tue Sep 12 2017 fstrba@suse.com
- Specify java source and target level 1.6 to allow building with
  jdk9
* Mon Mar  2 2015 tchvatal@suse.com
- Version bump to 1.2.17 latest 1.2 series:
  * No short changelog provided - many small changes
- Try to avoid cycle between log4j and apache-common-loggings
- Remove obsoleted patch:
  * log4j-jmx-Agent.patch
- Refresh patch to apply to new source:
  * log4j-mx4j-tools.patch
* Mon Mar  2 2015 tchvatal@suse.com
- Cleanup with a spec-cleaner so I can understand what
  is going around here.
* Thu Sep 12 2013 mvyskocil@suse.com
- log4j and log4j-mini are in conflict
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Jul 16 2013 mls@suse.de
- get rid of wrong dir modifier in filelist
* Thu Dec 10 2009 mvyskocil@suse.cz
- refreshed patches
  * log4j-javadoc-xlink.patch
  * log4j-jmx-Agent.patch
  * log4j-logfactor5-userdir.patch
  * log4j-mx4j-tools.patch
* Wed Jul 16 2008 coolo@suse.de
- even more packages to build ignore
* Fri Jun 27 2008 coolo@suse.de
- avoid build cycle between axis and log4j
* Tue May  6 2008 mvyskocil@suse.cz
- removed a dots in a names of geronimo-* packages
* Tue Apr  8 2008 mvyskocil@suse.cz
- updated to 1.2.5 [bnc#355798]
- merged a spec with jpackage 1.7
  - the ant arguments was splitted to several lines
  - new BuildRequires:
  - classpathx-javamail
  - geronimo-jaf
  - geronimo-jms
  - a new patches to break of a dependendy on Sun's HtmlAdaptorServer
    (replaced by HttpAdaptor from mx4j package)
  - added a gjc build branch
- created an autogenerated -mini specfile used for bootstrap (hint from sbrabec@suse.cz)
  - added an explicit provides of log4j symbol for log4j-mini (automatically by script)
- replaced a name `macro' by `real', because the -mini package has a different name
- disable the javadoc and manual subpackages for -mini build
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Fri May 18 2007 dbornkessel@suse.de
- removed mx4j BuildReq to avoid build cycle ... apparently it was not used at compile time
* Tue May  8 2007 dbornkessel@suse.de
- use mx4j instead of jmx
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 jsmeix@suse.de
- Current version 1.2.12 from JPackage.org
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Nov 25 2004 ro@suse.de
- added suse_update_desktop_file
* Thu Sep 23 2004 mskibbe@suse.de
- change specfile(suse_update_desktop_file)
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires for javadoc subpackage.
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 1.2.8 (JPackage 1.5)
